#
# spec file for package kf6-syntax-highlighting
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.7.0

%define rname syntax-highlighting
# Full KF6 version (e.g. 6.9.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-syntax-highlighting
Version:        6.9.0
Release:        1.1
Summary:        Syntax highlighting engine and library
License:        LGPL-2.1-or-later AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND MIT AND BSD-3-Clause AND Artistic-1.0
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_bugfix_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(xerces-c)

%description
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%package imports
Summary:        QML components for syntax-highlighting
Requires:       libKF6SyntaxHighlighting6 = %{version}

%description imports
This package contains QML imports for syntax-highlighting.

%package -n libKF6SyntaxHighlighting6
Summary:        Syntax highlighting engine and library
Recommends:     kf6-syntax-highlighting = %{version}

%description -n libKF6SyntaxHighlighting6
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%package devel
Summary:        Syntax highlighting engine and library
Requires:       kf6-extra-cmake-modules
Requires:       libKF6SyntaxHighlighting6 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}
Requires:       cmake(Qt6Gui) >= %{qt6_version}

%description devel
This is a tier1/functional version of the Kate syntax highlighting engine.
It's not tied to a particular output format or editor engine.

%lang_package -n libKF6SyntaxHighlighting6

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%fdupes %{buildroot}

%find_lang syntaxhighlighting6 --with-qt --without-mo

%ldconfig_scriptlets -n libKF6SyntaxHighlighting6

%files -n libKF6SyntaxHighlighting6-lang -f syntaxhighlighting6.lang

%files
%{_kf6_bindir}/ksyntaxhighlighter6
%{_kf6_debugdir}/ksyntaxhighlighting.categories
%{_kf6_debugdir}/ksyntaxhighlighting.renamecategories

%files imports
%{_kf6_qmldir}/org/kde/syntaxhighlighting/

%files -n libKF6SyntaxHighlighting6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6SyntaxHighlighting.so.*

%files devel
%doc %{_kf6_qchdir}/KF6SyntaxHighlighting.*
%{_kf6_cmakedir}/KF6SyntaxHighlighting/
%{_kf6_includedir}/KSyntaxHighlighting/
%{_kf6_libdir}/libKF6SyntaxHighlighting.so

%changelog
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.9.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.9.0
- Changes since 6.8.0:
  * Update dependency version to 6.9.0
  * Update odin highlighting
  * The lua indenter was removed long ago in ktexteditor
  * odin: Fix numbers getting highlighted in the middle of words
  * Highlight odin 'context' keyword differently
  * Improve odin lang highlighting
  * Bump KF and QT versions in ecm_set_disabled_deprecation_versions
  * cmake.xml: updates for the recently released CMake 3.31
  * Update version to 6.9.0
* Mon Nov  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.8.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.8.0
- Changes since 6.7.0:
  * Update dependency version to 6.8.0
  * State: Fix inconsistent linkage warning on Windows
  * better contrast for search highlighting (kde#494599)
  * odin: Add escape character to strings
  * update
  * add comments
  * Add TLA+ syntax highlighting
  * init
  * move try to cflow_begin
  * Update version to 6.8.0
* Mon Oct  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.7.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.7.0
- Changes since 6.6.0:
  * Update dependency version to 6.7.0
  * upload the uncompressed files
  * odin: add missing items, fix attribute, add directive
  * Swift: fix detection of end of protocol method declaration (kde#493459)
  * Indexer: treats 1-character StringDetect as a DetectChar for unreachable rules and the merge suggestion
  * Indexer: check that WordDetect does not contain spaces at the beginning and end of text
  * simplify installed xml syntax files to speed up reading
  * Indexer: replace some QString with QStringView and QLatin1Char with char16_t literal
  * Indexer: fix default value for char with LineContinuation
  * orgmode.xml: Fix orgmode syntax highlighting not ending properly
  * Jira, Markdown, Org Mode: use rhtml syntax with erb language
  * Haml: complete the syntax and fix the highlighting of Ruby line following the change in ruby.xml
  * Ruby: fix %%W, dot member, some parenthesis ; add ?c, escape char, etc (kde#488014)
  * Gleam: Minor modifications to syntax and example file
  * Remove truncase from Common Lisp
  * Update version to 6.7.0
* Sat Sep  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.6.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.6.0
- Too many changes since 6.5.0, only listing bugfixes:
  * PHP: add \{ in double quote string as a Backslash Code (kde#486372)
  * Bash: fix escaped line in brace condition (kde#487978)
  * Nix: fix string in attribute access (kde#491436)
* Mon Aug  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.5.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.5.0
- Changes since 6.4.0:
  * Update dependency version to 6.5.0
  * earthfile.xml: modernize highlighter to support Earthly 0.8 features
  * C++: add floating-point literal suffixes of C++23
  * Python: add some special variables and fix '\' line continuation after a string
  * add .clang-format and .clang-tidy files with YAML
  * Zig: fix range operator preceded by a number: [0..]
  * Odin: add raw string color
  * Update syntax highlighting for kdesrc-buildrc
  * Update version to 6.5.0
  * cmake.xml: update syntax for CMake 3.30
  * inc version after done type adding
  * hare: add done keyword
* Tue Jul  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.4.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.4.0
- Changes since 6.3.0:
  * Add CustomType highlighting and improve import highlighting
  * Corrected Gleam syntax
  * Add Gleam syntax
  * OrgMode: add header-item folding, properties folding, more todo keywords
  * avoid that we try to open files without name
  * [dracula.theme] Fix "ISO/Delphi Extended" for Pascal.
  * nginx: update for new directives and variables
  * systemd unit: update to systemd v256
  * Add basic syntax highlighting rules for opsi-script
  * [dracula.theme] Fix "Special Variable" for PHP.
  * Add Typst highlighter
* Wed Jun  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.3.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/6/6.3.0/
- Changes since 6.2.0:
  * Updates to Catppuccin themes
  * nix: Version 2 -> 3
  * nix: Correctly highlight first key in set when it is quoted
  * nix: Correctly highlight bare ${}
  * nix: More correctly model inherit syntax
  * build with QT_NO_CONTEXTLESS_CONNECT
  * Remove explicit maintainer from metainfo
  * Use ellipsis character instead of three dots in UI strings
  * xml: add fictionbook format
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- Changes since 6.1.0:
  * Support single-quoted strings in MapCSS
  * Add Syntax Highlighting for Vue Template Files
  * Add syntax highlighting support for CashScript
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
  * cmake-generator: refactor XML optimizations
  * cmake.xml: `has-target-names-after-kw` could be a list
  * cmake.xml: updates for the recently released CMake 3.29
  * cpp: Update Qt classes for Qt 6
  * initial gprbuild references
  * gprbuild: add license info
  * add small GPR test file
  * Add GPRbuild syntax
  * Add common alternative names used in various markdown parsers for languages
  * fix refs for stan
  * Update 2 files
  * use (?:sub){0,2} to work with all pcre versions
  * Alternate Names for Definitions
  * Fix implicit size -> int conversion
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
  * OCaml: unicode escapes in strings
  * OCaml: add quoted strings
  * OCaml: hex,octal,binary integer and hex floating point literals
  * OCaml: _ is valid identifier start
  * OCaml: update list of modules
  * OCaml: add Ok/Error variant tags
  * OCaml: update list of types
  * OCaml: update Stdlib functions
  * OCaml: add "initializer" keyword
  * OCaml: "closed" is not a keyword
  * OCaml: bump syntax highlighting version
  * fix kate-editor.org update for 6.x
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-syntax-highlighting
